summaryrefslogtreecommitdiff
path: root/sw/source/core/layout/pagedesc.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/core/layout/pagedesc.cxx')
-rw-r--r--sw/source/core/layout/pagedesc.cxx29
1 files changed, 19 insertions, 10 deletions
diff --git a/sw/source/core/layout/pagedesc.cxx b/sw/source/core/layout/pagedesc.cxx
index 87f9259b8292..01b238178cf4 100644
--- a/sw/source/core/layout/pagedesc.cxx
+++ b/sw/source/core/layout/pagedesc.cxx
@@ -73,7 +73,7 @@ SwPageDesc::SwPageDesc( const String& rName, SwFrmFmt *pFmt, SwDoc *pDc ) :
nRegHeight( 0 ),
nRegAscent( 0 ),
eUse( (UseOnPage)(nsUseOnPage::PD_ALL | nsUseOnPage::PD_HEADERSHARE | nsUseOnPage::PD_FOOTERSHARE) ),
- bLandscape( FALSE ),
+ bLandscape( sal_False ),
aFtnInfo()
{
}
@@ -175,16 +175,16 @@ void SwPageDesc::ResetAllAttr( sal_Bool bLeft )
// erfrage vom Modify Informationen
-BOOL SwPageDesc::GetInfo( SfxPoolItem & rInfo ) const
+sal_Bool SwPageDesc::GetInfo( SfxPoolItem & rInfo ) const
{
// if( RES_AUTOFMT_DOCNODE == rInfo.Which() )
// {
// dann weiter zum Format
if( !aMaster.GetInfo( rInfo ) )
- return FALSE; // gefunden
+ return sal_False; // gefunden
return aLeft.GetInfo( rInfo );
// }
// return TRUE; // weiter suchen
}
/*************************************************************************
@@ -289,8 +289,13 @@ void SwPageDesc::RegisterChange()
void SwPageDesc::Modify( const SfxPoolItem* pOld, const SfxPoolItem *pNew )
{
+<<<<<<< local
const USHORT nWhich = pOld ? pOld->Which() : pNew ? pNew->Which() : 0;
NotifyClients( pOld, pNew );
+=======
+ const sal_uInt16 nWhich = pOld ? pOld->Which() : pNew ? pNew->Which() : 0;
+ SwModify::Modify( pOld, pNew );
+>>>>>>> other
if ( (RES_ATTRSET_CHG == nWhich) || (RES_FMT_CHG == nWhich)
|| isCHRATR(nWhich) || (RES_PARATR_LINESPACING == nWhich) )
@@ -302,7 +307,7 @@ void SwPageDesc::Modify( const SfxPoolItem* pOld, const SfxPoolItem *pNew )
static const SwFrm* lcl_GetFrmOfNode( const SwNode& rNd )
{
SwModify* pMod;
- USHORT nFrmType = FRM_CNTNT;
+ sal_uInt16 nFrmType = FRM_CNTNT;
if( rNd.IsCntntNode() )
{
@@ -317,7 +322,11 @@ static const SwFrm* lcl_GetFrmOfNode( const SwNode& rNd )
pMod = 0;
Point aNullPt;
+<<<<<<< local
return pMod ? ::GetFrmOfModify( 0, *pMod, nFrmType, &aNullPt, 0, FALSE )
+=======
+ return pMod ? ::GetFrmOfModify( *pMod, nFrmType, &aNullPt, 0, sal_False )
+>>>>>>> other
: 0;
}
@@ -331,7 +340,7 @@ const SwPageDesc* SwPageDesc::GetPageDescOfNode(const SwNode& rNd)
}
const SwFrmFmt* SwPageDesc::GetPageFmtOfNode( const SwNode& rNd,
- BOOL bCheckForThisPgDc ) const
+ sal_Bool bCheckForThisPgDc ) const
{
// welches PageDescFormat ist fuer diesen Node gueltig?
const SwFrmFmt* pRet;
@@ -355,9 +364,9 @@ const SwFrmFmt* SwPageDesc::GetPageFmtOfNode( const SwNode& rNd,
return pRet;
}
-BOOL SwPageDesc::IsFollowNextPageOfNode( const SwNode& rNd ) const
+sal_Bool SwPageDesc::IsFollowNextPageOfNode( const SwNode& rNd ) const
{
- BOOL bRet = FALSE;
+ sal_Bool bRet = sal_False;
if( GetFollow() && this != GetFollow() )
{
const SwFrm* pChkFrm = lcl_GetFrmOfNode( rNd );
@@ -366,7 +375,7 @@ BOOL SwPageDesc::IsFollowNextPageOfNode( const SwNode& rNd ) const
( !pChkFrm->GetNext() || GetFollow() ==
((SwPageFrm*)pChkFrm->GetNext())->GetPageDesc() ))
// die Seite gefunden, auf die der Follow verweist
- bRet = TRUE;
+ bRet = sal_True;
}
return bRet;
}
@@ -442,7 +451,7 @@ SwPageFtnInfo &SwPageFtnInfo::operator=( const SwPageFtnInfo& rCpy )
-BOOL SwPageFtnInfo::operator==( const SwPageFtnInfo& rCmp ) const
+sal_Bool SwPageFtnInfo::operator==( const SwPageFtnInfo& rCmp ) const
{
return ( nMaxHeight == rCmp.GetHeight() &&
nLineWidth == rCmp.nLineWidth &&
@@ -175,16 +175,16 @@ void SwPageDesc::ResetAllAttr( sal_Bool bLeft )
return aLeft.GetInfo( rInfo );
// }
-// return TRUE; // weiter suchen
+// return sal_True; // weiter suchen
}
/*************************************************************************